@@ -3,7 +3,8 @@ import os
 import fairies as fa
 from xpinyin import Pinyin
 import re
-import pylcs
+# import pylcs
+from navinfo_tool import utils
 import collections
 from tqdm import tqdm
 from navinfo_tool import end_words, same_stroke
@@ -100,7 +101,8 @@ def find_disorder(text_list):
             if len(a) > len(b):
                 a, b = b, a
 
-            coml = pylcs.lcs(a, b)
+            # coml = pylcs.lcs(a, b)
+            coml = len(utils.getLCS(a, b))
 
             reversestr = ''
             preversestr = ''
@@ -109,7 +111,8 @@ def find_disorder(text_list):
                 if len(a) >= window:
                     for start in range(len(a) - window + 1):
                         reversea = a[:start] + ''.join(list(reversed(a[start: start + window]))) + a[start + window:]
-                        revcomlen = pylcs.lcs(reversea, b)
+                        # revcomlen = pylcs.lcs(reversea, b)
+                        revcomlen = len(utils.getLCS(reversea, b))
                         if revcomlen > maxcoml:
                             maxcoml = revcomlen
                             flagb = True
