@@ -448,6 +448,21 @@ def write_excel(filename, data, sheet_name='Sheet1'):
     workbook.close()
 
 
+def read_txt(fileName):
+
+    """
+        读取txt文件， 返回list， 每行内容为元素
+    """
+
+    res = []
+    with open(fileName, "r" ,encoding='utf8') as f:
+        data = f.readlines()
+        for d in tqdm(data):
+            res.append(d.strip('\n'))
+
+    return res
+
+
 def compute_vecsimilar_one_2_one(veca, vecb):
     """
     计算一个向量和另一个向量之间的相似度
